Module: Devise::JWT::RevocationStrategies::Denylist

Extended by:
ActiveSupport::Concern
Defined in:
lib/devise/jwt/revocation_strategies/denylist.rb

Overview

This strategy must be included in an ActiveRecord model, and requires that it has a jti column.

In order to tell whether a token is revoked, it just checks whether jti is in the table. On revocation, creates a new record with it.